# perform gstreamer imports (python3 style)
import gi
gi.require_version('Gst','1.0')

from gi.repository import GObject

from threading import Thread
import time

# import from this module 
from basicplayer import BasicPlayer

class MonitorThread(Thread):
    def __init__(self,player):
        self.player = player
        Thread.__init__(self)
        self.daemon = True      # as in: don't wait on this thread to quit
        self._running = False

    def stop(self):
        if self._running:
            self._running = False
            #self.join(0.5)
    
    def run(self):
        self._running = True
        while self._running:
            if self.player.player_state == "PLAYING" and self.player.playtime > 0:
                position = self.player.position()
                if (position - self.player.startpos) >= self.player.playtime:
                    self.player._finished()
            if self._running and time is not None:
                time.sleep(0.2)
        pass

class AudioPlayer(BasicPlayer):

    def __init__(self):
        BasicPlayer.__init__(self)
        # setup monitor thread
        self.monitor = MonitorThread(self)
        self.monitor.start()
        self.playtime = -1
        
    def __del__(self):
        self.monitor.stop()
        
    def playfor(self,duration):
        if duration > 0:    # not much point in wasting system resources otherwise
            self.startpos = self.position()
            self.playtime = duration
#            self.monitor.start()
            BasicPlayer.play(self)
        elif duration < 0: # same as normal play
            self.play()

    def play(self):
        if self.player_state != "PAUSED":
            self.playtime = -1;
        BasicPlayer.play(self)
        
    def stop(self):
        self.playtime = -1;
        BasicPlayer.stop(self)
        #self.monitor.stop()

GObject.type_register(AudioPlayer)
    